@@ -4,8 +4,8 @@ import urllib2
 from urlparse import urljoin, urlparse
 
 from django.conf import settings
-from django.views.decorators.csrf import csrf_exempt
 from django.views.generic import View
+from django.utils.decorators import classonlymethod
 
 from .response import HttpProxyResponse
 from .utils import normalize_headers, NoHTTPRedirectHandler
@@ -19,7 +19,12 @@ class ProxyView(View):
     diazo_theme_template = None
     html5 = False
 
-    @csrf_exempt
+    @classonlymethod
+    def as_view(cls, **initkwargs):
+        view = super(ProxyView, cls).as_view(**initkwargs)
+        view.csrf_exempt = True
+        return view
+
     def dispatch(self, request, path):
         request_headers = normalize_headers(request)
 
